summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/itemprop.cc
diff options
context:
space:
mode:
Diffstat (limited to 'crawl-ref/source/itemprop.cc')
-rw-r--r--crawl-ref/source/itemprop.cc6
1 files changed, 4 insertions, 2 deletions
diff --git a/crawl-ref/source/itemprop.cc b/crawl-ref/source/itemprop.cc
index 21fd25c77c..faea323e9a 100644
--- a/crawl-ref/source/itemprop.cc
+++ b/crawl-ref/source/itemprop.cc
@@ -505,9 +505,11 @@ void do_curse_item( item_def &item, bool quiet )
{
amusement *= 2;
// Cursed cloaks prevent you from removing body armour.
if (item.base_type == OBJ_ARMOUR
- && get_armour_slot(item) == EQ_CLOAK)
+ && (get_armour_slot(item) == EQ_CLOAK
+ || get_armour_slot(item) == EQ_GLOVES))
{
amusement *= 2;
}
@@ -505,9 +505,11 @@ void do_curse_item( item_def &item, bool quiet )
{
amusement *= 2;
- // Cursed cloaks prevent you from removing body armour.
+ // Cursed cloaks prevent you from removing body armour,
+ // gloves from switching rings.
if (item.base_type == OBJ_ARMOUR